class ConsoleConfig::EmailServer < ConsoleConfig::Base
  column :server, :string
  column :port, :integer
  column :domain, :string
  column :tls, :boolean
  column :authentication, :string
  column :user_name, :string
  column :password, :string
  column :from_address, :string
  column :from_name, :string
  
  validates_presence_of :port, :server
  validates_length_of :server, :user_name, :domain, :from_name, :from_address, 
      :allow_blank => true, :in => 1..255
  validates_numericality_of  :port, :allow_nil => true, :only_integer => true, :message => 'must be an integer'
  validates_inclusion_of     :port, :in => 1..65535, :allow_nil => true, :message => 'must be between 1-65535'
  
  validates_presence_of :user_name, :if => :authentication_login?
  validates_presence_of :ui_password, :message => "^Password can't be blank", :if => :password_required? 
  validates_confirmation_of :ui_password, :message => "^Confirmation doesn't match password", :if => :check_password_confirmation?
  validates_length_of :ui_password, 
        :within => 1..255,  
        :too_short => "^Password must be between 1-255 characters.", 
        :too_long  => "^Password must be between 1-255 characters.", 
        :allow_blank => true 

  enum_helper :authentication, ['none', 'login']
  default_value_for :authentication, AUTHENTICATION_NONE
  
  attr_accessor :ui_password, :ui_password_confirmation
  
  def test_configuration(recipient_email)
		begin
			Notifier.deliver_email_settings_test(recipient_email)
		rescue Timeout::Error
			$email_test_output << "Timed out when trying to contact mail server.\n"
		end
	end
	
  def save_settings 
    self.password = ui_password unless ui_password.blank? 
    super 
  end 

  def password_required?
    authentication_login? && password.blank?
  end
  
  def check_password_confirmation?
    authentication_login? && (ui_password.present? || ui_password_confirmation.present?)
  end
  
  class << self
    
    def from(name = nil)
      cached_from_name = from_name
      cached_from_address = from_address

      name = name.blank? ? cached_from_name : name
      name = name.blank? ? nil : %("#{name}")
      address = cached_from_address.blank? ? nil : "<#{cached_from_address}>"
      [name, address].compact.join(' ')
    end
    
    # Returns the address that emails are sent "To".  (Email recipeients are put 
    # in the "bcc" of the email.)
    def to
      email_regexp = /[\w\.\+_%-]+@[\w\.-]+\.[a-zA-Z]{2,4}/  # contains an email
      from_name_address = from
      
      if from_name_address =~ email_regexp
        from_name_address
      else
        cached_user_name = user_name(:cached)
        if cached_user_name.to_s =~ email_regexp
          cached_user_name
        else
          nil
        end
      end
    end
    
  end
end